<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Gdpr_Cookie_Banner
 * @subpackage Gdpr_Cookie_Banner/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Gdpr_Cookie_Banner
 * @subpackage Gdpr_Cookie_Banner/admin
 * @author     Your Name <email@example.com>
 */
class Gdpr_Cookie_Banner_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $gdpr_cookie_banner    The ID of this plugin.
	 */
	private $gdpr_cookie_banner;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $gdpr_cookie_banner       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $gdpr_cookie_banner, $version ) {

		$this->gdpr_cookie_banner = $gdpr_cookie_banner;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gdpr_Cookie_Banner_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gdpr_Cookie_Banner_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->gdpr_cookie_banner.'-1', plugin_dir_url( __FILE__ ) . 'css/jquery.fontselect.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->gdpr_cookie_banner.'-2', plugin_dir_url( __FILE__ ) . 'css/gdpr-cookie-banner-admin.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'wp-color-picker' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gdpr_Cookie_Banner_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gdpr_Cookie_Banner_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->gdpr_cookie_banner.'-1', plugin_dir_url( __FILE__ ) . 'js/jquery.fontselect.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->gdpr_cookie_banner.'-2', plugin_dir_url( __FILE__ ) . 'js/gdpr-cookie-banner-admin.js', array( 'jquery', $this->gdpr_cookie_banner.'-1' ), $this->version, true );
		wp_enqueue_script( 'wp-color-picker');

	}


	/**
	 * Display the Settings link on the plugin admin screen after the plugi activation
	 * 
	 * @since	1.0.0
	 */
	public function pp_gdpr_cookie_banner_settings_link( $links ) {
		
		$links[] = '<a href="' .
			admin_url( 'options-general.php?page=gdpr-cookie-banner' ) .
			'">' . __( 'Settings', 'gdpr-cookie-banner' ) . '</a>';
		return $links;
	}
	
	/**
	 * Register the plugin settings and add the sections on the plugin's settings screen
	 * 
	 * @since	1.0.0
	 */
	public function pp_admin_display_options() {
		
		//section name, form element name, callback for sanitization
		register_setting( "pp_gdpr_cookie_banner_options", "pp_cookie_popup_message", array( 'sanitize_callback' => array( $this, 'pp_sanitize_cookie_popup_message' ) ) );
		register_setting( "pp_gdpr_cookie_banner_options", "pp_banner_position", array( 'sanitize_callback' => array( $this, 'pp_sanitize_banner_position' ) ) );
		register_setting( "pp_gdpr_cookie_banner_options", "pp_banner_size", array( 'sanitize_callback' => array( $this, 'pp_sanitize_banner_size' ) ) );
		register_setting( "pp_gdpr_cookie_banner_options", "pp_banner_background_color", array( 'sanitize_callback' => array( $this, 'pp_sanitize_banner_background_color' ) ) );
		register_setting( "pp_gdpr_cookie_banner_options", "pp_banner_font", array( 'sanitize_callback' => array( $this, 'pp_sanitize_banner_font' ) ) );
		register_setting( "pp_gdpr_cookie_banner_options", "pp_banner_font_size", array( 'sanitize_callback' => array( $this, 'pp_sanitize_banner_font_size' ) ) );

		//section name, display name, callback to print description of section, page to which section is attached.
        add_settings_section( "pp_gdpr_cookie_banner_section", __( "General Settings", "gdpr-cookie-banner" ), array( $this, "pp_display_header_options_content" ), $this->gdpr_cookie_banner );
		add_settings_field( "pp_cookie_popup_message", __( "Banner Message", "gdpr-cookie-banner" ), array( $this, "pp_display_cookie_popup_message" ), $this->gdpr_cookie_banner, "pp_gdpr_cookie_banner_section" );
		add_settings_field( "pp_banner_position", __( "Banner Position", "gdpr-cookie-banner" ), array( $this, "pp_display_banner_position" ), $this->gdpr_cookie_banner, "pp_gdpr_cookie_banner_section" );
		add_settings_field( "pp_banner_size", __( "Banner Size", "gdpr-cookie-banner" ), array( $this, "pp_display_banner_size" ), $this->gdpr_cookie_banner, "pp_gdpr_cookie_banner_section" );
		add_settings_field( "pp_banner_background_color", __( "Background Color", "gdpr-cookie-banner" ), array( $this, "pp_display_banner_background_color" ), $this->gdpr_cookie_banner, "pp_gdpr_cookie_banner_section" );
		add_settings_field( "pp_banner_font", __( "Banner Font", "gdpr-cookie-banner" ), array( $this, "pp_display_banner_font"), $this->gdpr_cookie_banner, "pp_gdpr_cookie_banner_section" );
		add_settings_field( "pp_banner_font_size", __( "Banner Font Size", "gdpr-cookie-banner" ), array( $this, "pp_display_banner_font_size" ), $this->gdpr_cookie_banner, "pp_gdpr_cookie_banner_section" );
	}


	/**
	 * Display the header on the plugin's settings screen
	 * 
	 * @since	1.0.0
	 */
	public function pp_display_header_options_content() {
		
		echo __( "Settings For GDPR Cookie Banner", "gdpr-cookie-banner" );
	}


	/**
	 * Display the cookie popup message field on the plugin's settings screen
	 * 
	 * @since	1.0.0
	 */
	public function pp_display_cookie_popup_message() {

		$pp_cookie_popup_message = get_option( 'pp_cookie_popup_message' );

		if ( ! isset( $pp_cookie_popup_message ) ) {
		
			?>
			<textarea name="<?php echo esc_attr( 'pp_cookie_popup_message' ); ?>" id="<?php echo esc_attr( 'pp_cookie_popup_message' ); ?>"><?php echo esc_html__( "Banner Message Goes Here.....", "gdpr-cookie-banner" ); ?></textarea>
			<?php
		}
		else{
			
			?>
			<textarea name="<?php echo esc_attr( 'pp_cookie_popup_message' ); ?>" id="<?php echo esc_attr( 'pp_cookie_popup_message' ); ?>"><?php echo esc_html( $pp_cookie_popup_message ); ?></textarea>
			<?php
		}
	}

	/**
	 * Display the banner position field on the plugin's settings screen
	 * 
	 * @since	1.0.0
	 */
	public function pp_display_banner_position() {

		$pp_banner_position = get_option( 'pp_banner_position' );

		if ( isset( $pp_banner_position ) && 'top' === $pp_banner_position ) {
			?>
			<input type="radio" id="<?php echo esc_attr( 'pp_banner_position' ); ?>" name="<?php echo esc_attr( 'pp_banner_position' ); ?>" value="<?php echo esc_attr( 'bottom' ); ?>"><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Bottom", "gdpr-cookie-banner" ); ?></span>
			<input type="radio" id="<?php echo esc_attr( 'pp_banner_position' ); ?>" name="<?php echo esc_attr( 'pp_banner_position' ); ?>" value="<?php echo esc_attr('top'); ?>" checked><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Top", "gdpr-cookie-banner"); ?></span>
			<?php
		}
		else {
			?>
			<input type="radio" id="<?php echo esc_attr( 'pp_banner_position' ); ?>" name="<?php echo esc_attr( 'pp_banner_position' ); ?>" value="<?php echo esc_attr( 'bottom' ); ?>" checked><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Bottom", "gdpr-cookie-banner" ); ?></span>
			<input type="radio" id="<?php echo esc_attr( 'pp_banner_position' ); ?>" name="<?php echo esc_attr( 'pp_banner_position' ); ?>" value="<?php echo esc_attr( 'top' ); ?>"><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Top", "gdpr-cookie-banner" ); ?></span>
			<?php
		}
	}

	/**
	 * Display the banner size field on the plugin's settings screen
	 * 
	 * @since	1.0.0
	 */
	public function pp_display_banner_size() {

		$pp_banner_size = get_option( 'pp_banner_size' );

		if ( isset( $pp_banner_size ) && 'small' === $pp_banner_size ) {
			?>
			<input type="radio" id="<?php echo esc_attr( 'pp_banner_size' ); ?>" name="<?php echo esc_attr( 'pp_banner_size' ); ?>" value="<?php echo esc_attr( 'large' ); ?>"><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Large", "gdpr-cookie-banner" ); ?></span>
			<input type="radio" id="<?php echo esc_attr( 'pp_banner_size' ); ?>" name="<?php echo esc_attr( 'pp_banner_size' ); ?>" value="<?php echo esc_attr( 'medium' ); ?>"><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Medium", "gdpr-cookie-banner" ); ?></span>
			<input type="radio" id="<?php echo esc_attr( 'pp_banner_size' ); ?>" name="<?php echo esc_attr( 'pp_banner_size' ); ?>" value="<?php echo esc_attr( 'small' ); ?>" checked><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Small", "gdpr-cookie-banner" ); ?></span>
			<?php
		}
		else if ( isset( $pp_banner_size ) && 'medium' === $pp_banner_size ) {
			?>
			<input type="radio" id="<?php echo esc_attr('pp_banner_size'); ?>" name="<?php echo esc_attr( 'pp_banner_size' ); ?>" value="<?php echo esc_attr( 'large' ); ?>"><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Large", "gdpr-cookie-banner" ); ?></span>
			<input type="radio" id="<?php echo esc_attr('pp_banner_size'); ?>" name="<?php echo esc_attr( 'pp_banner_size' ); ?>" value="<?php echo esc_attr( 'medium' ); ?>"checked><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Medium", "gdpr-cookie-banner" ); ?></span>
			<input type="radio" id="<?php echo esc_attr('pp_banner_size'); ?>" name="<?php echo esc_attr( 'pp_banner_size' ); ?>" value="<?php echo esc_attr( 'small' ); ?>"><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Small", "gdpr-cookie-banner" ); ?></span>
			<?php
		}
		else {
			?>
			<input type="radio" id="<?php echo esc_attr( 'pp_banner_size' ); ?>" name="<?php echo esc_attr( 'pp_banner_size' ); ?>" value="<?php echo esc_attr( 'large' ); ?>" checked><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Large", "gdpr-cookie-banner" ); ?></span>
			<input type="radio" id="<?php echo esc_attr( 'pp_banner_size' ); ?>" name="<?php echo esc_attr( 'pp_banner_size' ); ?>" value="<?php echo esc_attr( 'medium' ); ?>"><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Medium", "gdpr-cookie-banner" ); ?></span>
			<input type="radio" id="<?php echo esc_attr( 'pp_banner_size' ); ?>" name="<?php echo esc_attr( 'pp_banner_size' ); ?>" value="<?php echo esc_attr( 'small' ); ?>"><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Small", "gdpr-cookie-banner" ); ?></span>
			<?php
		}
	}

	/**
	 * Display the banner background color field on the plugin's settings screen
	 * 
	 * @since	1.0.0
	 */
	public function pp_display_banner_background_color() {

		$pp_banner_background_color = get_option( 'pp_banner_background_color' );

		if( isset( $pp_banner_background_color ) && 'light' === $pp_banner_background_color ) {
			?>
			<div class="<?php echo esc_attr( 'custom-css-section' ); ?>">
				<input type="radio" id="<?php echo esc_attr( 'pp_banner_background_color' ); ?>" name="<?php echo esc_attr( 'pp_banner_background_color' ); ?>" value="<?php echo esc_attr( 'dark' ); ?>"><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Dark", "gdpr-cookie-banner" ); ?><span class="background-color-section cms-dark-bg"></span></span>
				<input type="radio" id="<?php echo esc_attr( 'pp_banner_background_color' ); ?>" name="<?php echo esc_attr( 'pp_banner_background_color' ); ?>" value="<?php echo esc_attr( 'light' ); ?>" checked><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Light", "gdpr-cookie-banner" ); ?><span class="background-color-section cms-light-bg"></span></span>
			</div>
			<?php
		}
		else {

			?>
			<div class="<?php echo esc_attr( 'custom-css-section' ); ?>">
				<input type="radio" id="<?php echo esc_attr( 'pp_banner_background_color' ); ?>" name="<?php echo esc_attr( 'pp_banner_background_color' ); ?>" value="<?php echo esc_attr( 'dark' ); ?>" checked><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Dark", "gdpr-cookie-banner" ); ?><span class="background-color-section cms-dark-bg"></span></span>
				<input type="radio" id="<?php echo esc_attr( 'pp_banner_background_color' ); ?>" name="<?php echo esc_attr( 'pp_banner_background_color' ); ?>" value="<?php echo esc_attr( 'light' ); ?>"><span class="<?php echo esc_attr( 'radio-input-name' ); ?>"><?php echo esc_html__( "Light", "gdpr-cookie-banner" ); ?><span class="background-color-section cms-light-bg"></span></span>
			</div>
			<?php
		}
	}

	/**
	 * Display the banner font field on the plugin's settings screen
	 * 
	 * @since	1.0.0
	 */
	public function pp_display_banner_font() {

		$pp_banner_font = get_option( 'pp_banner_font' );
		?>
		<div class="<?php echo esc_attr( 'custom-css-section' ); ?>">
			<input id="<?php echo esc_attr( 'pp_banner_font' ); ?>" type="text" name="<?php echo esc_attr( 'pp_banner_font' ); ?>"<?php if( isset( $pp_banner_font ) ){ ?> data-selected-font="<?php echo esc_attr( $pp_banner_font ); } ?>">
		</div>
		<?php
	}


	/**
	 * Display the banner font size field on the plugin's settings screen
	 * 
	 * @since	1.0.0
	 */
	public function pp_display_banner_font_size() {

		$pp_banner_font_size = get_option( 'pp_banner_font_size' );

		?>
		<div class="<?php echo esc_attr( 'custom-css-section' ); ?>">
			<select id="<?php echo esc_attr( 'pp_banner_font_size' ); ?>" name="<?php echo esc_attr( 'pp_banner_font_size' ); ?>">
				<?php

					for($i=1;$i<26;$i++){
						?>
						<option value="<?php echo esc_attr($i); ?>"<?php if( isset( $pp_banner_font_size ) && $pp_banner_font_size == $i ){ echo " selected"; }?>><?php echo esc_html__( "$i", "gdpr-cookie-banner" ); ?></option>
						<?php
					}
				?>
			</select>
		</div>
		<?php
	}

	/**
	 * Add the plugin settings link under Settings menu in the admin dashboard
	 * 
	 * @since	1.0.0
	 */
	public function pp_add_admin_menu() {

		add_options_page( __( 'GDPR Cookie Banner', 'gdpr-cookie-banner' ), __( 'GDPR Cookie Banner', 'gdpr-cookie-banner' ), 'administrator', $this->gdpr_cookie_banner, array( $this, 'pp_admin_settings_page' ) );
	}

	/**
	 * Load the html for the plugin settings
	 * 
	 * @since	1.0.0
	 */
	public function pp_admin_settings_page() {

		include_once 'partials/gdpr-cookie-banner-admin-display.php';
	}


	/* Sanitization functions for registered settings starts here */

	/**
	 * Sanitize the cookie popup message field
	 * 
	 * @since	1.0.0
	 */
	public function pp_sanitize_cookie_popup_message($message) {

		$message = trim( $message );
		$filtered_message =  wp_kses(
			$message,
			array(
				'a' => array(
					'href' => array(),
					'title' => array()
				)
			),
			array(
				'http',
				'https'
			)
		);


		if( '' === $filtered_message ) {
			
			add_settings_error( 'pp_cookie_popup_message', 'pp_cookie_popup_message_error', __( 'Banner Message cannot be blank', 'gdpr-cookie-banner' ), 'error' );
		}

		return $filtered_message;
	}

	/**
	 * Sanitize the banner position field
	 * 
	 * @since	1.0.0
	 */
	public function pp_sanitize_banner_position( $banner_position ) {

		$banner_position = strip_tags(stripslashes( trim( $banner_position ) ) );
		$banner_position_array = array( 'top', 'bottom' );

		if( '' === $banner_position ) {

			add_settings_error( 'pp_banner_position', 'pp_banner_position_error', __( 'Banner Position field is required', 'gdpr-cookie-banner' ), 'error' );
		}
		else if( ! in_array( $banner_position, $banner_position_array ) ){

			add_settings_error( 'pp_banner_position', 'pp_banner_position_error', __( 'Banner Position field is not valid', 'gdpr-cookie-banner' ), 'error' );
		}
		
		return sanitize_text_field( $banner_position );
	}

	/**
	 * Sanitize the banner size field
	 * 
	 * @since	1.0.0
	 */
	public function pp_sanitize_banner_size( $banner_size ) {

		$banner_size = strip_tags(stripslashes( trim( $banner_size) ) );
		$banner_size_array = array( 'small', 'medium', 'large' );

		if('' === $banner_size ) {

			add_settings_error( 'pp_banner_size', 'pp_banner_size_error', __( 'Banner Size field is required', 'gdpr-cookie-banner' ), 'error' );
		}
		else if( ! in_array( $banner_size, $banner_size_array ) ) {

			add_settings_error( 'pp_banner_size', 'pp_banner_size_error', __( 'Banner Size field is not valid', 'gdpr-cookie-banner' ), 'error' );
		}
		
		return sanitize_text_field( $banner_size );
	}

	/**
	 * Sanitize the banner background color field
	 * 
	 * @since	1.0.0
	 */
	public function pp_sanitize_banner_background_color( $banner_background_color ) {

		$banner_background_color = strip_tags( stripslashes( trim( $banner_background_color ) ) );
		return sanitize_text_field( $banner_background_color );
	}

	/**
	 * Sanitize the banner font field
	 * 
	 * @since	1.0.0
	 */
	public function pp_sanitize_banner_font( $banner_font ) {

		$banner_font = strip_tags(stripslashes( trim( $banner_font ) ) );
		if( '' === $banner_font ) {

			add_settings_error( 'pp_banner_font', 'pp_banner_font_error', __( 'Banner Font field is required', 'gdpr-cookie-banner' ), 'error' );
		}
		return sanitize_text_field( $banner_font );
	}

	/**
	 * Sanitize the banner font size
	 * 
	 * @since	1.0.0
	 */
	public function pp_sanitize_banner_font_size( $banner_font_size ) {

		$banner_font_size = strip_tags( stripslashes( trim( $banner_font_size ) ) );
		if('' === $banner_font_size ) {

			add_settings_error( 'pp_banner_font_size', 'pp_banner_font_size_error', __( 'Banner Font Size field is required', 'gdpr-cookie-banner' ), 'error' );
		}
		return sanitize_text_field( $banner_font_size );
	}

	/* Sanitization functions for registered settings ends here */

}
