<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @since             1.0.0
 * @package           Gdpr_Cookie_Banner
 *
 * @wordpress-plugin
 * Plugin Name:       GDPR Cookie Banner
 * Description:       GDPR Cookie Banner helps website owners to display a notice that they are using cookies.
 * Version:           1.0.0
 * Author:            The PaperPlane Team
 * Author URI:        http://www.paperplane.net
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       gdpr-cookie-banner
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'GDPR_COOKIE_BANNER_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-gdpr-cookie-banner-activator.php
 */
function activate_gdpr_cookie_banner() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gdpr-cookie-banner-activator.php';
	Gdpr_Cookie_Banner_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-gdpr-cookie-banner-deactivator.php
 */
function deactivate_gdpr_cookie_banner() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gdpr-cookie-banner-deactivator.php';
	Gdpr_Cookie_Banner_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_gdpr_cookie_banner' );
register_deactivation_hook( __FILE__, 'deactivate_gdpr_cookie_banner' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-gdpr-cookie-banner.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_gdpr_cookie_banner() {

	Gdpr_Cookie_Banner::$basename = plugin_basename( __FILE__ );
	$plugin = new Gdpr_Cookie_Banner();
	$plugin->run();
}
run_gdpr_cookie_banner();
