<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Gdpr_Cookie_Banner
 * @subpackage Gdpr_Cookie_Banner/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Gdpr_Cookie_Banner
 * @subpackage Gdpr_Cookie_Banner/public
 * @author     Your Name <email@example.com>
 */
class Gdpr_Cookie_Banner_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $gdpr_cookie_banner    The ID of this plugin.
	 */
	private $gdpr_cookie_banner;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $gdpr_cookie_banner       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $gdpr_cookie_banner, $version ) {

		$this->gdpr_cookie_banner = $gdpr_cookie_banner;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gdpr_Cookie_Banner_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gdpr_Cookie_Banner_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		
		wp_enqueue_style( $this->gdpr_cookie_banner, plugin_dir_url( __FILE__ ) . 'css/gdpr-cookie-banner-public.css', array(), $this->version, 'all' );
		
		$pp_banner_text_font = get_option( 'pp_banner_font' );
		$pp_banner_text_font_weight = 400;
		$custom_css = '';


		/**
		 * Add the font which user has selected on the plugin's settings page. Add it below the plugin's css file.
		 */
		if( isset( $pp_banner_text_font ) && '' !== $pp_banner_text_font ) {

			wp_enqueue_style( $this->gdpr_cookie_banner . '-google-font-styles', '//fonts.googleapis.com/css?family=' . $pp_banner_text_font, array(), $this->version, 'all' );
			$pp_banner_text_font = str_replace( '+', ' ', $pp_banner_text_font );

			if( false !== strpos( $pp_banner_text_font, ':' ) ) {

				$pp_banner_text_font_weight = substr($pp_banner_text_font, strpos( $pp_banner_text_font, ':' ) + 1 );
				$pp_banner_text_font = str_replace( substr($pp_banner_text_font, strpos( $pp_banner_text_font, ':' ) ), '', $pp_banner_text_font );
			}


			$pp_banner_text_font = '"'.$pp_banner_text_font.'"';
			$custom_css .= "
					.cookies-description{
							font-family:{$pp_banner_text_font};
							font-weight:{$pp_banner_text_font_weight};
						";
		}
		
		/**
		 * Add the font size which user has selected on the plugin's settings page. Add it below the plugin's css file.
		 */
		$pp_banner_text_font_size = get_option( 'pp_banner_font_size' );
		if( isset( $pp_banner_text_font_size ) && '' !== $pp_banner_text_font_size ) {

			$pp_banner_text_line_height = $pp_banner_text_font_size + 4 . 'px';
			$pp_banner_text_font_size = $pp_banner_text_font_size .'px';

			if( '' != $custom_css ) {
				
				$custom_css .= "
				
								font-size:{$pp_banner_text_font_size};
								line-height:{$pp_banner_text_line_height};
						";
			} else {

				$custom_css .= "
						.cookies-description{
								font-size:{$pp_banner_text_font_size};
								line-height:{$pp_banner_text_line_height};
						";
			}
		}
		if( '' !== $custom_css ) {

			
			$custom_css .= "

				}
			";
			wp_add_inline_style( $this->gdpr_cookie_banner, $custom_css );
		}
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gdpr_Cookie_Banner_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gdpr_Cookie_Banner_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->gdpr_cookie_banner, plugin_dir_url( __FILE__ ) . 'js/gdpr-cookie-banner-public.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Load the gdpr cookie banner html file that is to be displayed on the front-end
	 *
	 * @since    1.0.0
	 */
	public function display_banner() {

		include_once 'partials/gdpr-cookie-banner-public-display.php';
	}
}
